#' @importFrom utils globalVariables
globalVariables(unique(c(
  ".",
  # random_ggplot
  "Sepal.Length", "Sepal.Width", "Species", "Petal.Width",
  "mpg", "disp", "vs", "wt", "qsec", "cyl",
  "Solar.R", "Wind", "Month", "Temp", "Ozone",
  "Var1", "Freq",
  "date", "unemploy",
  "waiting", "eruptions", "density",
  "year", "month", "median",
  "height", "weight",
  "speed", "dist",
  "x", "y",
  "depth", "cut", "carat", "price", "color",
  "year", "level",
  "z", "w"

  # random dygraphs
  # @importFrom datasets mdeaths fdeaths ldeaths nhtemp AirPassengers discoveries presidents austres
  # random_ggplot
  # @importFrom datasets iris mtcars airquality women cars LakeHuron faithful
  # random_print
  # @importFrom datasets iris mtcars airquality
  # random_table
  # @importFrom datasets iris ability.cov anscombe attitude beaver1 CO2 esoph longley
  # @importFrom datasets mtcars Puromycin ToothGrowth OrchardSprays InsectSprays

)))
